# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "biorad_phd"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&||||||||||P|LIS-A2|20130715141912
    P|1||||NYME^ANO
    O|1|123456||^^^A,1:10\\^^^B|R|20130513114242|||||N
    O|2|123456||^^^C|R|20130513114242|||||C
    L|1|N
    """
    assert message == expected


def test_void_order_query(self):
    worklist = self.encode(
        self.void_worklist,
        context={
            "query": self.parse(
                """
        H|\\^&|||PhD_EIA^3|||||||P|LIS2-A2|20091210112248
        Q|1|^43210^||^^^ALL||||||||O
        L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&||||||||||P|LIS-A2|20130715141912
    P|1
    O|1|43210|||R||||||Y
    L|1|N"""
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&|||PhD_EIA^3|||||||P|LIS-A2|20100414091021
    P|1
    O|1|638297^ENAPanel^3||^^^Sm|R||||||||||||||||||||F
    R|1|^^^Sm^QUANT|32.00|EU||||F|||20100414091021|20100414122625
    R|2|^^^Sm^QUAL^^^F|Positive|||||F|||20100414091021|20100414122625
    R|3|^^^aCL_IgA^QUANT|>76.00|APL||>||F|||20100414091021|20100414122625
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "638297",
                "rack": "ENAPanel-3",
                "results": [
                    {
                        "code": "Sm1QUANT",
                        "date": datetime.datetime(2010, 4, 14, 12, 26, 25),
                        "value": "32.00",
                        "unit": "EU",
                    },
                    {
                        "code": "Sm1QUAL",
                        "date": datetime.datetime(2010, 4, 14, 12, 26, 25),
                        "value": "Positive",
                    },
                    {
                        "code": "aCL_IgA1QUANT",
                        "date": datetime.datetime(2010, 4, 14, 12, 26, 25),
                        "value": ">76.00",
                        "unit": "APL",
                        "flags": [">"],
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
    H|\\^&|||PhD_EIA^3|||||||P|LIS-A2|20100414091021
    P|1
    O|1|Blank^ENAPanel^||^^^Sm|R||||||Q||||||||||||||F
    R|1|^^^Sm^QUANT|0.00|EU||||F|||20100414091021|20100414122625
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "Blank",
                "control_lot": "Blank",
                "results": [
                    {
                        "code": "Sm1QUANT",
                        "date": datetime.datetime(2010, 4, 14, 12, 26, 25),
                        "value": "0.00",
                        "unit": "EU",
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control_with_option(self):
    self.configure(phd_qc_prefix="QC")
    worklist = self.decode(
        """
    H|\\^&|||PhD_EIA^3|||||||P|LIS-A2|20100414091021
    P|1
    O|1|QCBlank^ENAPanel^||^^^Sm|R||||||||||||||||||||F
    R|1|^^^Sm^QUANT|0.00|EU||||F|||20100414091021|20100414122625
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "QCBlank",
                "control_lot": "QCBlank",
                "results": [
                    {
                        "code": "Sm1QUANT",
                        "date": datetime.datetime(2010, 4, 14, 12, 26, 25),
                        "value": "0.00",
                        "unit": "EU",
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|||PhD_EIA^3|||||||P|LIS2-A2|20091210112248
    Q|1|^43210^||^^^ALL||||||||O
    L|1|N
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "43210"}],
    }
    assert worklist == expected


def test_decode_cq(self):
    self.configure(phd_qc_prefix="QC")
    worklist = self.decode(
        """
    H|\\^&|||PhD_EIA^3|||||||P|LIS2-A2|20180927153243
    P|41||||^^^^
    O|1|CAL^2018-09-27 13-51-dl^||^^^ANA6|R||||||Q||||||||||||||F
    R|1|^^^ANA6^QUANT|0.72|UE||||F
    P|42||||^^^^
    O|1|REF^2018-09-27 13-51-dl^||^^^ANA6|R||||||Q||||||||||||||F
    R|1|^^^ANA6^QUANT|100.00|UE||||F
    P|43||||^^^^
    O|1|QCECTAI06^2018-09-27 13-51-dl^6||^^^ANA6|R||||||||||||||||||||F
    R|1|^^^ANA6^QUANT|237.95|UE||||F
    R|2|^^^ANA6^QUAL^^^F|positiffort|||||F
    P|44||||^^^^
    O|1|QCECTAI06^2018-09-27 13-51-dl^6||^^^ANA6|R||||||||||||||||||||F
    R|1|^^^ANA6^QUANT|58.13|UE||||F
    R|2|^^^ANA6^QUAL^^^F|positif|||||F
    P|45||||^^^^
    O|1|QCECTAI06^2018-09-27 13-51-dl^6||^^^ANA6|R||||||||||||||||||||F
    R|1|^^^ANA6^QUANT|4.05|UE||||F
    R|2|^^^ANA6^QUAL^^^F|negatif|||||F
    P|46||||^^^^
    O|1|QCECTAI06^2018-09-27 13-51-dl^6||^^^ANA6|R||||||||||||||||||||F
    R|1|^^^ANA6^QUANT|103.00|UE||||F
    R|2|^^^ANA6^QUAL^^^F|positif|||||F
    P|47||||^^^^
    O|1|QCECTAI06^2018-09-27 13-51-dl^6||^^^ANA6|R||||||||||||||||||||F
    R|1|^^^ANA6^QUANT|1.83|UE||||F
    R|2|^^^ANA6^QUAL^^^F|negatif|||||F
    P|48||||^^^^
    O|1|QCECTAI06^2018-09-27 13-51-dl^6||^^^ANA6|R||||||||||||||||||||F
    R|1|^^^ANA6^QUANT|1.83|UE||||F
    R|2|^^^ANA6^QUAL^^^F|negatif|||||F
    L|1|N
    """
    )
    date = datetime.datetime(2018, 9, 27, 15, 32, 43)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "sample_id": "QCECTAI06",
                "control_lot": "QCECTAI06",
                "results": [
                    {
                        "code": "ANA61QUANT",
                        "date": date,
                        "unit": "UE",
                        "value": "237.95",
                    },
                    {"code": "ANA61QUAL", "date": date, "value": "positiffort"},
                    {
                        "code": "ANA62QUANT",
                        "date": date,
                        "unit": "UE",
                        "value": "58.13",
                    },
                    {"code": "ANA62QUAL", "date": date, "value": "positif"},
                    {"code": "ANA63QUANT", "date": date, "unit": "UE", "value": "4.05"},
                    {"code": "ANA63QUAL", "date": date, "value": "negatif"},
                    {
                        "code": "ANA64QUANT",
                        "date": date,
                        "unit": "UE",
                        "value": "103.00",
                    },
                    {"code": "ANA64QUAL", "date": date, "value": "positif"},
                    {"code": "ANA65QUANT", "date": date, "unit": "UE", "value": "1.83"},
                    {"code": "ANA65QUAL", "date": date, "value": "negatif"},
                    {"code": "ANA66QUANT", "date": date, "unit": "UE", "value": "1.83"},
                    {"code": "ANA66QUAL", "date": date, "value": "negatif"},
                ],
            }
        ],
    }
    assert worklist == expected
