# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "cfx_biorad"


def test_decode_result(self):
    # Les lignes peuvent avoir plus de 6 champs
    worklist = self.decode(
        """
        File Name,20201209 RUN1.pcrd,,,,,
    Created By User,admin,,,,,
    Notes,,,,,,
    ID,,,,,,
    Run Started,12/09/2020 11:38:26 UTC,,,,,
    Run Ended,12/09/2020 13:15:47 UTC,,,,,
    Sample Vol,30,,,,,
    Lid Temp,105,,,,,
    Protocol File Name,SARS CoV2 ELITeMGB.prcl,,,,,
    Plate Setup File Name,20201209 RUN1.pltd,,,,,
    Base Serial Number,CT052169,,,,,
    Optical Head Serial Number,785BR27808,,,,,
    CFX Maestro Version,5.0.021.0616. ,,,,,
    ,,,,,,
    Well group,All Wells,,,,,
    Amplification step,4,,,,,
    Melt step,,,,,,
    ,,,,,,
    ,,,,,,
    Well,Fluor,Target,Content,Sample,Cq,Starting Quantity (SQ)
    A01,FAM,ORF 8,Unkn-01,5812090070,NaN,NaN
    A02,FAM,ORF 8,Unkn-09,5812090091,NaN,NaN
    A03,FAM,ORF 8,Unkn-17,5812090101,23.5126419411208,NaN
    A04,FAM,ORF 8,Unkn-25,5812090116,NaN,NaN
    A05,FAM,ORF 8,Unkn-33,,NaN,NaN
    A06,FAM,ORF 8,Unkn-41,,NaN,NaN
    """
    )
    assert worklist.samples
    trames = """
    File Name,CFX Sansure.pcrd,,,,
    Created By User,adminavec des accent èà ^ðŋħĸ,,,,
    Notes,Plaque1,,,,
    ID,,,,,
    Run Started,04/06/2020 12:37:05 UTC,,,,
    Run Ended,04/06/2020 13:00:40 UTC,,,,
    Sample Vol,50,,,,
    Lid Temp,105,,,,
    Protocol File Name,SansureProtocole.prcl,,,,
    Plate Setup File Name,CFX Sansure.pltd,,,,
    Base Serial Number,SIM01944,,,,
    Optical Head Serial Number,788BR02720,,,,
    CFX Maestro Version,4.1.2433.1219. ,,,,
    ,,,,,
    Well group,All Wells,,,,
    Amplification step,4,,,,
    Melt step,,,,,
    ,,,,,
    ,,,,,
    Well,Fluor,Target,Content,Sample,Cq
    A01,Cy5,IPC,Pos Ctrl-01,123456,14.76039106
    A02,Cy5,IPC,Unkn-07,135790,12.38063612
    A03,Cy5,IPC,Unkn-15,987652,12.37989111
    A04,Cy5,IPC,Unkn-23,123453,12.81727096
    """
    self.configure(analyseur_traites="SIM01944")
    worklist = self.decode(trames)
    date_resu = datetime.datetime(2020, 4, 6, 13, 0, 40)
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "CFX-A01",
                "results": [
                    {"code": "File Name", "value": "CFX Sansure"},
                    {"code": "Notes", "value": "Plaque1"},
                    {
                        "code": "Created By User",
                        "value": "adminavec des accent èà ^ðŋħĸ",
                    },
                    {"code": "RACK", "value": "A01"},
                    {
                        "code": "IPC",
                        "instrument": "SIM01944",
                        "value": "14.76039106",
                        "date": date_resu,
                        "comments": ["Plaque1"],
                        "operator": "adminavec des accent èà ^ðŋħĸ",
                    },
                    {
                        "code": "Cy5IPC",
                        "instrument": "SIM01944",
                        "value": "14.76039106",
                        "date": date_resu,
                        "comments": ["Plaque1"],
                        "operator": "adminavec des accent èà ^ðŋħĸ",
                    },
                ],
                "sample_id": "123456",
                "type": "patient",
            },
            {
                "rack": "CFX-A02",
                "results": [
                    {"code": "File Name", "value": "CFX Sansure"},
                    {"code": "Notes", "value": "Plaque1"},
                    {
                        "code": "Created By User",
                        "value": "adminavec des accent èà ^ðŋħĸ",
                    },
                    {"code": "RACK", "value": "A02"},
                    {
                        "code": "IPC",
                        "instrument": "SIM01944",
                        "value": "12.38063612",
                        "date": date_resu,
                        "comments": ["Plaque1"],
                        "operator": "adminavec des accent èà ^ðŋħĸ",
                    },
                    {
                        "code": "Cy5IPC",
                        "instrument": "SIM01944",
                        "value": "12.38063612",
                        "date": date_resu,
                        "comments": ["Plaque1"],
                        "operator": "adminavec des accent èà ^ðŋħĸ",
                    },
                ],
                "sample_id": "135790",
                "type": "patient",
            },
            {
                "rack": "CFX-A03",
                "results": [
                    {"code": "File Name", "value": "CFX Sansure"},
                    {"code": "Notes", "value": "Plaque1"},
                    {
                        "code": "Created By User",
                        "value": "adminavec des accent èà ^ðŋħĸ",
                    },
                    {"code": "RACK", "value": "A03"},
                    {
                        "code": "IPC",
                        "instrument": "SIM01944",
                        "value": "12.37989111",
                        "date": date_resu,
                        "comments": ["Plaque1"],
                        "operator": "adminavec des accent èà ^ðŋħĸ",
                    },
                    {
                        "code": "Cy5IPC",
                        "instrument": "SIM01944",
                        "value": "12.37989111",
                        "date": date_resu,
                        "comments": ["Plaque1"],
                        "operator": "adminavec des accent èà ^ðŋħĸ",
                    },
                ],
                "sample_id": "987652",
                "type": "patient",
            },
            {
                "rack": "CFX-A04",
                "results": [
                    {"code": "File Name", "value": "CFX Sansure"},
                    {"code": "Notes", "value": "Plaque1"},
                    {
                        "code": "Created By User",
                        "value": "adminavec des accent èà ^ðŋħĸ",
                    },
                    {"code": "RACK", "value": "A04"},
                    {
                        "code": "IPC",
                        "instrument": "SIM01944",
                        "value": "12.81727096",
                        "date": date_resu,
                        "comments": ["Plaque1"],
                        "operator": "adminavec des accent èà ^ðŋħĸ",
                    },
                    {
                        "code": "Cy5IPC",
                        "instrument": "SIM01944",
                        "value": "12.81727096",
                        "date": date_resu,
                        "comments": ["Plaque1"],
                        "operator": "adminavec des accent èà ^ðŋħĸ",
                    },
                ],
                "sample_id": "123453",
                "type": "patient",
            },
        ],
    }
    assert worklist == expected
    self.configure(analyseur_traites="SIM01944")
    worklist = self.decode(trames)
    assert worklist == expected
    self.configure(analyseur_traites="")
    worklist = self.decode(trames)
    assert worklist == expected
    self.configure(analyseur_traites="XXXX")
    worklist = self.decode(trames)
    assert len(worklist.samples) == 0


def test_decode_extra_results(self):
    self.configure(extra_results=True)
    worklist = self.decode(
        """
        File Name,testvivien2.pcrd,,,,,,
    Created By User,admin,,,,,,
    Notes,notes,,,,,,
    ID,,,,,,,
    Run Started,05/31/2021 10:49:48 UTC,,,,,,
    Run Ended,05/31/2021 12:01:30 UTC,,,,,,
    Sample Vol,13,,,,,,
    Lid Temp,105,,,,,,
    Protocol File Name,Protocole kit QUADRIPLEX IdSol.prcl,,,,,,
    Plate Setup File Name,CRIB-2021.05.31.S1.ECFX3.AMGIA.pltd,,,,,,
    Base Serial Number,CT047811,,,,,,
    Optical Head Serial Number,785BR25721,,,,,,
    CFX Maestro Version,4.1.2433.1219. ,,,,,,
    ,,,,,,,
    Well group,All Wells,,,,,,
    Amplification step,4,,,,,,
    Melt step,,,,,,,
    ,,,,,,,
    ,,,,,,,
    Well,Fluor,Target,Content,Sample,Cq,Call,End RFU
    C06,Cy5,Endogene,Unkn-30,19E180031548,25.0059924876803,,2107.34494280569
    C06,FAM,SARS-CoV-2,Unkn-30,19E180031548,NaN,,237.933427943401
    C06,HEX,SPIKE N501Y,Unkn-30,19E180031548,NaN,,6.19242099372141
    C06,ROX,SPIKE E484K,Unkn-30,19E180031548,NaN,,10.0838490882084
    """
    )
    date_resu = datetime.datetime(2021, 5, 31, 12, 1, 30)
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "CFX-C06",
                "sample_id": "19E180031548",
                "type": "patient",
                "results": [
                    {"code": "File Name", "value": "testvivien2"},
                    {"code": "Notes", "value": "notes"},
                    {"code": "Created By User", "value": "admin"},
                    {"code": "RACK", "value": "C06"},
                    {
                        "code": "Cy5EndogeneCq",
                        "comments": ["notes"],
                        "date": date_resu,
                        "instrument": "CT047811",
                        "operator": "admin",
                        "value": "25.0059924876803",
                    },
                    {
                        "code": "Cy5EndogeneEnd RFU",
                        "comments": ["notes"],
                        "date": date_resu,
                        "instrument": "CT047811",
                        "operator": "admin",
                        "value": "2107.34494280569",
                    },
                    {
                        "code": "FAMSARS-CoV-2Cq",
                        "comments": ["notes"],
                        "date": date_resu,
                        "instrument": "CT047811",
                        "operator": "admin",
                        "value": "NaN",
                    },
                    {
                        "code": "FAMSARS-CoV-2End RFU",
                        "comments": ["notes"],
                        "date": date_resu,
                        "instrument": "CT047811",
                        "operator": "admin",
                        "value": "237.933427943401",
                    },
                    {
                        "code": "HEXSPIKE N501YCq",
                        "comments": ["notes"],
                        "date": date_resu,
                        "instrument": "CT047811",
                        "operator": "admin",
                        "value": "NaN",
                    },
                    {
                        "code": "HEXSPIKE N501YEnd RFU",
                        "comments": ["notes"],
                        "date": date_resu,
                        "instrument": "CT047811",
                        "operator": "admin",
                        "value": "6.19242099372141",
                    },
                    {
                        "code": "ROXSPIKE E484KCq",
                        "comments": ["notes"],
                        "date": date_resu,
                        "instrument": "CT047811",
                        "operator": "admin",
                        "value": "NaN",
                    },
                    {
                        "code": "ROXSPIKE E484KEnd RFU",
                        "comments": ["notes"],
                        "date": date_resu,
                        "instrument": "CT047811",
                        "operator": "admin",
                        "value": "10.0838490882084",
                    },
                ],
            }
        ],
    }
    assert worklist == expected
