# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "elecsys"


def test_order(self):
    result = self.order(
        context={
            "query": self.parse(
                """ H|\\^&
            Q|1|^123456^278^0^19^^SAMPLE^NORMAL||ALL||||||||O
            L|1"""
            )
        }
    )
    expected = """H|\\^&||||||||||P|1|20130715141912
        P|1|036666666|||NYME^ANO|NJF||F
        O|1|123456|278|^^^A\\^^^B|S|20130603110342|20130513114242||||N||||||||||||||Q
        O|2|123456|278|^^^C|S|20130603110342|20130513114242||||C||||||||||||||Q
        L|1|F"""
    assert result == expected


def test_void_order(self):
    result = self.order(
        worklist=self.void_worklist,
        context={
            "query": self.parse(
                """
                H|\\^&
                Q|1|^123456^278^0^19^^SAMPLE^NORMAL||ALL||||||||O
                L|1"""
            )
        },
    )
    expected = """
    H|\\^&||||||||||P|1|20130715141912
    L|1|F"""
    assert result == expected


def test_result(self):
    result = self.decode(
        """
    H|\\^&||||||||||P
    P|1
    O|1|53221400|804^00146^4^^SAMPLE^NORMAL|ALL|R|20140111120335|||||X||||||||||||||O
    R|1|^^^90^^0|9.14|pg/ml|0.000^14.00|N||F|||20140111120605|20140111121600
    R|2|^^^271^^0|194.2|pg/ml|0.000^9999999|N||F|||20140111120647|20140111122506
    C|1|I|50^Resultat inferieur au domaine de mesure|I
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "53221400",
                "rack": "00146-4",
                "type": "patient",
                "results": [
                    {
                        "code": "90",
                        "value": "9.14",
                        "flags": ["N"],
                        "date": datetime.datetime(2014, 1, 11, 12, 16, 0),
                        "comments": [],
                    },
                    {
                        "code": "271",
                        "value": "194.2",
                        "flags": ["N"],
                        "date": datetime.datetime(2014, 1, 11, 12, 25, 6),
                        "comments": ["Resultat inferieur au domaine de mesure"],
                    },
                ],
            }
        ],
    }
    assert result == expected


def test_query(self):
    result = self.decode(
        """
    H|\\^&
    Q|1|^000004^278^0^19^^SAMPLE^NORMAL||ALL||||||||O
    L|1"""
    )
    expected = {
        "context": "query",
        "samples": [{"sample_id": "000004", "type": "patient"}],
    }
    assert result == expected


def test_qc(self):
    result = self.decode(
        """
    H|\\^&||||||||||P||
    P|1|||||||||||||||||||||||||||||||||
    O|1|PC CARD2|4647^00146^4^^CONTROL^NORMAL|ALL|R|20140612081507|||||X\\Q||||||||||||||O|||||
    R|1|^^^271^^0|5146|pg/ml|3985^5735|N||F|||20140612081744|20140612083604|
    L|1"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "PC CARD2",
                "type": "control",
                "control_lot": "PC CARD2",
                "results": [
                    {
                        "date": datetime.datetime(2014, 6, 12, 8, 36, 4),
                        "value": "5146",
                        "code": "271",
                        "flags": ["N"],
                        "comments": [],
                    }
                ],
            }
        ],
    }
    assert result == expected
