# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "indiko"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&||||||||||P||20130715141912
    P|1|L036666666|||NYME ANO||20110513|F|||||||||||||||||PRESCRIBER
    O|1|123456||^^^A^1:10|A||20130513114242||||N||||Serum||||||||||O
    O|2|123456||^^^B|A||20130513114242||||A||||Serum||||||||||O
    L|1|N
    """
    assert message == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&|||1^Analyzer_1^|||||||P||20101118143705
    P|1|PatientID_07|||Patient Name_7||||||||||||||||||||||||||||
    O|1|SampleID_07^0.0^5^1||^^^ISE_test^0|R||||||X||||3|||||||||1|F
    R|1|^^^ISE_test^5|0.00675|umol/l||||||||20101118143620|Analyzer_1
    O|2|SampleID_07^0.0^5^1||^^^Photo_reflex_test^5|R||||||X||||3|||||||||1|F
    R|1|^^^Photo_reflex_test^0|0.74143|mmol/l||||||||20101118143621|Analyzer_1
    O|3|SampleID_07^0.0^5^1||^^^Photometric_test^5|R||||||X||||3|||||||||1|F
    R|1|^^^Photometric_test^0|0.80626|nmol/l||||||||20101118143620|Analyzer_1
    C|1|I|Comment1\\Comment2|G
    O|4|SampleID_07^0.0^5^1||^^^Reflex_test_done^5|S||||||X||||3|||||||||1|F
    R|1|^^^Reflex_test_done^5|0.18109|g/l||||||||20101118143705|Analyzer_1
    C|1|I|21 Test limit high\\30 Outside of cal.|I
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "SampleID_07",
                "rack": "0.0-5",
                "type": "patient",
                "results": [
                    {
                        "code": "ISE_test",
                        "value": "0.00675",
                        "flags": [],
                        "instrument": "Analyzer_1",
                        "operator": "",
                        "unit": "umol/l",
                        "date": datetime.datetime(2010, 11, 18, 14, 36, 20),
                        "comments": [],
                    },
                    {
                        "code": "Photo_reflex_test",
                        "value": "0.74143",
                        "flags": [],
                        "instrument": "Analyzer_1",
                        "operator": "",
                        "unit": "mmol/l",
                        "date": datetime.datetime(2010, 11, 18, 14, 36, 21),
                        "comments": [],
                    },
                    {
                        "code": "Photometric_test",
                        "value": "0.80626",
                        "flags": [],
                        "instrument": "Analyzer_1",
                        "operator": "",
                        "unit": "nmol/l",
                        "date": datetime.datetime(2010, 11, 18, 14, 36, 20),
                        "comments": ["Comment1", "Comment2"],
                    },
                    {
                        "code": "Reflex_test_done",
                        "value": "0.18109",
                        "flags": ["21 Test limit high", "30 Outside of cal."],
                        "instrument": "Analyzer_1",
                        "operator": "",
                        "unit": "g/l",
                        "date": datetime.datetime(2010, 11, 18, 14, 37, 5),
                        "comments": [],
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
    H|\\^&|||1^Analyzer 1^6.0|||||||Q||20181211163408
    P|1||||||||||||||||||||||||||||||||
    O|1|Ct Par TDM 1^0.0^401^12||^^^GENT^0.0|R||||||Q||||1|||||TDA 190801^1.39^1.390||||1|
    R|1|^^^GENT^0.0|1.21|µg/ml||N||F||Automatic||20181211163358|Analyzer 1
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "TDA 190801",
                "control_lot": "TDA 190801",
                "type": "control",
                "results": [
                    {
                        "code": "GENT",
                        "value": "1.21",
                        "flags": [],
                        "instrument": "Analyzer 1",
                        "operator": "Automatic",
                        "unit": "µg/ml",
                        "date": datetime.datetime(2018, 12, 11, 16, 33, 58),
                        "comments": [],
                    }
                ],
            }
        ],
    }
    assert worklist == expected
