# -*- coding: utf8 -*-
from __future__ import unicode_literals

parser_class = "quantstudio"


def test_decode_result(self):
    date = None
    worklist = self.decode(
        """
    COVID-19 Kit Analysis Data Export
    Software Version = COVID-19 Interpretive Software 2.3
    Date and Time of Export = 11/06/20  19:13:51
    Experiment Name = 2020-10-16_serie2 test
    Instrument Software Version = QuantStudio™ Design & Analysis Software v1.5.1
    Instrument Type = QuantStudio 5 System
    Instrument Serial Number = 272525680
    Run Start Date = Fri Oct 16 19:48:53 CEST 2020
    Run End Date = Fri Oct 16 20:56:04 CEST 2020
    Run Operator = eson
    Batch Status = VALID

    Batch ID,Sample Name,Well,Well Number,Sample Type,Manual Threshold,MS2 Manual Threshold,Baseline Start,MS2 Baseline Start,ORF1ab Ct,N gene Ct,S gene Ct,MS2 Ct,ORF1ab,N gene,S gene,MS2,ORF1ab BaselineEnd,N gene BaselineEnd,S gene BaselineEnd,MS2 BaselineEnd,Status,Interpretive Result,Action*
    2020-10-16_serie2 test,89123702870745,A02,1,Patient,5000.0,10000.0,5,5,,,,28.25985,NEGATIVE,NEGATIVE,NEGATIVE,POSITIVE,39,39,39,21,VALID,SARS-CoV-2 Not Detected,REPORT
    2020-10-16_serie2 test,89123902880212R,A01,0,Patient,5000.0,10000.0,5,5,19.774431,16.793997,20.427166,28.309229,POSITIVE,POSITIVE,POSITIVE,POSITIVE,15,12,14,22,VALID,Positive SARS-CoV-2,REPORT

    *See COVID-19 Kit IFU for reporting activities.
    CE-IVD
    For In Vitro Diagnostic Use.
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "A02",
                "results": [
                    {
                        "code": "Manual Threshold",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "5000.0",
                    },
                    {
                        "code": "MS2 Manual Threshold",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "10000.0",
                    },
                    {
                        "code": "Baseline Start",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "5",
                    },
                    {
                        "code": "MS2 Baseline Start",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "5",
                    },
                    {
                        "code": "MS2 Ct",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "28.25985",
                    },
                    {
                        "code": "ORF1ab",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "NEGATIVE",
                    },
                    {
                        "code": "N gene",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "NEGATIVE",
                    },
                    {
                        "code": "S gene",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "NEGATIVE",
                    },
                    {
                        "code": "MS2",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "POSITIVE",
                    },
                    {
                        "code": "ORF1ab BaselineEnd",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "39",
                    },
                    {
                        "code": "N gene BaselineEnd",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "39",
                    },
                    {
                        "code": "S gene BaselineEnd",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "39",
                    },
                    {
                        "code": "MS2 BaselineEnd",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "21",
                    },
                    {
                        "code": "Status",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "VALID",
                    },
                    {
                        "code": "Interpretive Result",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "SARS-CoV-2 Not Detected",
                    },
                    {
                        "code": "Action*",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "REPORT",
                    },
                ],
                "sample_id": "89123702870745",
                "type": "patient",
            },
            {
                "rack": "A01",
                "results": [
                    {
                        "code": "Manual Threshold",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "5000.0",
                    },
                    {
                        "code": "MS2 Manual Threshold",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "10000.0",
                    },
                    {
                        "code": "Baseline Start",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "5",
                    },
                    {
                        "code": "MS2 Baseline Start",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "5",
                    },
                    {
                        "code": "ORF1ab Ct",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "19.774431",
                    },
                    {
                        "code": "N gene Ct",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "16.793997",
                    },
                    {
                        "code": "S gene Ct",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "20.427166",
                    },
                    {
                        "code": "MS2 Ct",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "28.309229",
                    },
                    {
                        "code": "ORF1ab",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "POSITIVE",
                    },
                    {
                        "code": "N gene",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "POSITIVE",
                    },
                    {
                        "code": "S gene",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "POSITIVE",
                    },
                    {
                        "code": "MS2",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "POSITIVE",
                    },
                    {
                        "code": "ORF1ab BaselineEnd",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "15",
                    },
                    {
                        "code": "N gene BaselineEnd",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "12",
                    },
                    {
                        "code": "S gene BaselineEnd",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "14",
                    },
                    {
                        "code": "MS2 BaselineEnd",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "22",
                    },
                    {
                        "code": "Status",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "VALID",
                    },
                    {
                        "code": "Interpretive Result",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "Positive SARS-CoV-2",
                    },
                    {
                        "code": "Action*",
                        "date": date,
                        "instrument": "272525680",
                        "operator": "eson",
                        "value": "REPORT",
                    },
                ],
                "sample_id": "89123902880212R",
                "type": "patient",
            },
        ],
    }
    assert worklist == expected
