# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

from driverng.tests import BaseTest


class TestSapphire(BaseTest):
    MAPPING_CLASS = "sapphire"
    DATA0 = """H|\\^&|||42709AZ^^CDSapphire^v4^3.0|||||||P|LIS2-A
P|1||||TOTO MIMILE^||19121212|M|||||||^^^
O|1|519165^01^01|5172|^^^CBC^2^1|||20130319174800||||||||Patient^Human||||||||||F
C|1|I|DC^NONE|I
C|2|I|DI^00000^00000|I
C|3|I|SP^Nonviable WBCs^NO^0.00|I
C|4|I|SP^Bands^NO^0.00|I
C|5|I|SP^Blasts^NO^0.00|I
C|6|I|SP^Variant Lymphoids^NO^0.00|I
C|7|I|SP^Immature Granulocytes^YES^0.50|I
C|8|I|SP^Unidentified Fluorescent Cells^NO^0.00|I
C|9|I|SP^Resistant RBCs^YES^0.00|I
C|10|I|SP^Asymmetric RBC^NO^0.00|I
C|11|I|SP^High Number Immature Reticulocytes^NO^0.00|I
C|12|I|SP^Platelet Clumps^NO^0.00|I
R|1|^^^CBC^^^^WBC|4.84|||||F||cb|20130319180440||42709AZ
R|2|^^^CBC^^^^RETC|----|||||X||cb|20130319180440||42709AZ
R|3|^^^CBC^^^^%R|----|||||X||cb|20130319180440||42709AZ
R|4|^^^CBC^^^^IRF|----|||||X||cb|20130319180440||42709AZ
R|5|^^^CBC^^^^EOS|0.021|||||W||sl|20130319180440||42709AZ
L|1|N"""
    QUERY_ALL = """H|\\^&|||42709AZ^^CDSapphire^v5^3.0|||||||P|LIS2-A
Q|1|^ALL
L|1|N"""

    def test_result(self):
        self.assertResultEqual(
            self.DATA0,
            {
                "519165": {
                    "rack": "01-01",
                    "resultats": [
                        {
                            "test": "WBC",
                            "date": datetime.datetime(2013, 3, 19, 18, 4, 40),
                            "analyseur": "42709AZ",
                            "resu": "4.84",
                        },
                        {
                            "test": "ALARME",
                            "resu": "",
                            "analyseur": "42709AZ",
                            "commentaires": ["Immature Granulocytes", "Resistant RBCs"],
                        },
                    ],
                }
            },
        )

    def test_result_with_option(self):
        self.F.inclure_tous_status_resultats = True
        date = datetime.datetime(2013, 3, 19, 18, 4, 40)
        self.assertResultEqual(
            self.DATA0,
            {
                "519165": {
                    "rack": "01-01",
                    "resultats": [
                        {
                            "test": "WBC",
                            "date": date,
                            "analyseur": "42709AZ",
                            "resu": "4.84",
                        },
                        {
                            "test": "RETC",
                            "date": date,
                            "analyseur": "42709AZ",
                            "resu": "----",
                        },
                        {
                            "test": "%R",
                            "date": date,
                            "analyseur": "42709AZ",
                            "resu": "----",
                        },
                        {
                            "test": "IRF",
                            "date": date,
                            "analyseur": "42709AZ",
                            "resu": "----",
                        },
                        {
                            "test": "EOS",
                            "date": date,
                            "analyseur": "42709AZ",
                            "resu": "0.021",
                        },
                        {
                            "test": "ALARME",
                            "resu": "",
                            "analyseur": "42709AZ",
                            "commentaires": ["Immature Granulocytes", "Resistant RBCs"],
                        },
                    ],
                }
            },
        )

    def test_enregistrer_queryall(self):
        self.assertEqual(self.F.enregistrer(self.QUERY_ALL), False)
        self.assertEqual(self.F.enregistrer(self.DATA0), True)

    def test_order(self):
        self.assertOrderMessageEqual(
            self.WORKLIST_NEW_ADD_DEL,
            """
            H|\\^&||||||||||P|LIS2-A
            P|1||036666666||NYME ANO||20110513|F|||||PRS
            O|1|123456||^^^A\\^^^B|||20130513114242||||||||Patient^Human||||||||||F
            L|1|N""",
        )
